# CCAT-Prime Sensitivity Calculator

Install with `pip install sensitivity-calculator`

## Usage:

See usage.ipynb.

## Methods:

https://drive.google.com/file/d/1fHq5Xhym90HNmEvk_Yz6QRJ9zNLokPXO/view?usp=sharing

## Additional Requirements:

If data needs to be regenrated (such as due to updated PWV measurements), then run src/sensitivity_calculator/data/amDataGenerator.sh (with updated PWV values) with GNU bc 1.07.1 and am 12.0
